package com.zcloud.primeport.command.convertor;

import com.zcloud.primeport.domain.model.PersonApplyE;
import com.zcloud.primeport.dto.clientobject.PersonApplyCO;
import com.zcloud.primeport.dto.clientobject.PersonCountCO;
import com.zcloud.primeport.dto.clientobject.XgfPersonCountCO;
import com.zcloud.primeport.persistence.dataobject.PersonApplyDO;
import com.zcloud.primeport.persistence.dataobject.PersonCountDto;
import org.mapstruct.Mapper;

import java.util.List;


/**
 * web-app
 *
 * @Author makejava
 * @Date 2026-03-05 11:33:21
 */
@Mapper(componentModel = "spring")
public interface PersonApplyCoConvertor {
    /**
     * @param personApplyDOs
     * @return
     */
    PersonApplyCO converDOToCO(PersonApplyDO personApplyDO);
    List<PersonApplyCO> converDOsToCOs(List<PersonApplyDO> personApplyDOs);
    List<XgfPersonCountCO> converDOsToXgfCOs(List<PersonApplyDO> personApplyDOs);

    List<PersonCountCO> converDtosToCOs(List<PersonCountDto> data);
    List<PersonApplyCO> converEstosToCOs(List<PersonApplyE> data);
}

